(usage/table)=
# Table
<hr class="sn-grey">
<a 
    class="sphinx-bs badge badge-primary text-white reference external sn-api sn-link-container2"
    href="../autoapi/snowmobile/core/table/index.html" 
    title="API Documentation">
    <span>snowmobile.core.table</span>
</a>

```{admonition} Note
:class: note

See {class}`the snowmobile.core.table API docs<snowmobile.core.table.Table>`

[test](./autoapi/snowmobile/core/table/index.html#autoapi-snowmobile-core-table-index--page-root) 
```

<hr class="sn-grey">
